@@ -1,11 +1,12 @@
-import os.path
-import deskbar, deskbar.interfaces.Match, deskbar.interfaces.Module, deskbar.core.Utils
 from deskbar.core.GconfStore import GconfStore
-import gtk
-from gettext import gettext as _
-import xml.dom.minidom, urllib
 from deskbar.defs import VERSION
 from deskbar.handlers.actions.ShowUrlAction import ShowUrlAction
+from gettext import gettext as _
+import deskbar, deskbar.interfaces.Match, deskbar.interfaces.Module, deskbar.core.Utils
+import gconf
+import gtk
+import logging
+import xml.dom.minidom, urllib
 
 GCONF_DELICIOUS_USER  = GconfStore.GCONF_DIR+"/desklicious/user"
 
@@ -61,12 +62,12 @@ class DeliciousHandler(deskbar.interfaces.Module):
         #self.check_query_changed ()
         
         #The queryyyyYyyYy :)
-        print "Asking del.icio.us tags for %s" % tag
+        logging.info( "Asking del.icio.us tags for %s" % tag )
         posts = self._delicious.get_posts_by_tag(tag)
 
         # TODO: Missing
         #self.check_query_changed (timeout=QUERY_DELAY)
-        print 'Returning del.icio.us result'
+        logging.info('Returning del.icio.us result')
         self.set_priority_for_matches( posts )
         self._emit_query_ready(tag, posts )
         
@@ -127,10 +128,17 @@ class DeliciousTagQueryEngine:
             self._user = value.get_string()
             
     def get_posts_by_tag(self, tag):
+        if self._user == None:
+            return []
+        
         #Get the info from del.icio.us and parse
         url = DEFAULT_QUERY_TAG % (urllib.quote_plus(self._user), urllib.quote_plus(tag))
-
-        stream = urllib.urlopen(url, proxies=deskbar.core.Utils.get_proxy())
+        try:
+            stream = urllib.urlopen(url, proxies=deskbar.core.Utils.get_proxy())
+        except IOError, msg:
+            logging.error("Could not open URL %s: %s, %s" % (url, msg[0], msg[1]))
+            return []
+        
         dom = xml.dom.minidom.parse(stream)
         stream.close()
         
