@@ -18,14 +18,25 @@ class CuemiacWindowController(deskbar.interfaces.Controller):
         self._clipboard = gtk.clipboard_get (selection="PRIMARY")
         
     def on_keybinding_activated(self, core, time, paste=True):
-        if self._model.get_use_selection() and paste:
-            text = self._clipboard.wait_for_text()
-            if text != None:
-                self._view.get_entry().set_text(text)
-        self._view.receive_focus(time)
+        """
+        Toggle view if keybinding has been activated
+        """
+        if self._view.get_toplevel().get_property("visible"):
+            self.on_quit()
+        else:
+            if self._model.get_use_selection() and paste:
+                text = self._clipboard.wait_for_text()
+                if text != None:
+                    self._view.get_entry().set_text(text)
+            self._view.receive_focus(time)
         
     def on_quit(self, *args):
+        if self._model.get_clear_entry():
+            self._view.clear_all()
         window = self._view.get_toplevel()
+        x, y = window.get_position()      
+        self._model.set_window_x(x)      
+        self._model.set_window_y(y)
         window.hide()
         return True
 
@@ -44,8 +55,6 @@ class CuemiacWindowController(deskbar.interfaces.Controller):
         if (qstring != ""):
             self._view.show_results()
             self._model.query( qstring )
-        else:
-            self._view.set_clear()
             
     def on_query_entry_key_press_event(self, entry, event):
         # For key UP to browse in history, we have either to be already in history mode, or have an empty text entry to trigger hist. mode
