@@ -61,6 +61,7 @@ class DeskbarApplet (gtk.HBox):
         """
         gtk.HBox.__init__ (self)
         self.applet = applet
+        applet.set_background_widget(applet)
         self.popup_dir = applet.get_orient()
         
         if self.popup_dir in [gnomeapplet.ORIENT_UP,gnomeapplet.ORIENT_DOWN]:
@@ -86,18 +87,19 @@ class DeskbarApplet (gtk.HBox):
         
         self.on_change_size()
         
-        self.__setup_mvc()
         self.__setup_applet_menu()
+        self.__setup_mvc()
        
     def __setup_mvc(self):
         self.__core = CoreImpl(deskbar.MODULES_DIRS)
         self.__core.connect("loaded", self.__on_loaded)
-        self.__core.run()
         
         self.__controller = CuemiacWindowController(self.__core)
         self.__view = CuemiacWindowView(self.__controller, self.__core)
         self.__view.set_sensitive(False)
         
+        self.__core.run()
+        
     def __setup_applet_menu(self):
         self.applet.setup_menu_from_file (
             deskbar.SHARED_DATA_DIR, "Deskbar_Applet.xml",
@@ -124,10 +126,7 @@ class DeskbarApplet (gtk.HBox):
         self.__view.set_sensitive(True)
           
     def __show_toggle(self, widget, time):
-        if self.__view.get_toplevel().get_property("visible"):
-            self.__controller.on_quit()
-        else:
-            self.__controller.on_keybinding_activated(widget, time, False)
+        self.__controller.on_keybinding_activated(widget, time, False)
             
     def get_active_main (self):
         return self.button_main.get_active ()
